<?php
/*
Plugin Name: Pluga api
Plugin URI: https://pluginstech.com
Description: Faça integração simplificada com uma das melhores e mais baratas api do mercado integrado com woocommerce. Use dados dinâmicos ao enviar uma mensagem: {nome_cliente}, {email_cliente}, {itens_pedido}, {valor_total}, {id_pedido}
Version: 1.0
Author: Plugins Tech
Author URI: https://pluginstech.com
License: 
License URI: 
*/

// Verificar se o WooCommerce está ativo
if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    return;
}

// Adicionar menu lateral para o plugin
function plugsend_api_menu() {
    add_menu_page(
        'PlugSend API', 
        'PlugSend API', 
        'manage_options', 
        'plugsend-api', 
        'plugsend_api_page', 
        'dashicons-whatsapp', 
        99
    );
}
add_action('admin_menu', 'plugsend_api_menu');

// Adicionar estilos para a página de configuração
function plugsend_api_admin_styles() {
    ?>
    <style>
        .plugsend-container {
            background: linear-gradient(135deg, #f6f8f9 0%, #e5ebee 100%);
            padding: 30px;
            border-radius: 12px;
            box-shadow: 0 10px 25px rgba(0,0,0,0.1);
        }
        .plugsend-header {
            display: flex;
            align-items: center;
            justify-content: space-between;
            margin-bottom: 30px;
            padding-bottom: 20px;
            border-bottom: 2px solid #e0e0e0;
        }
        .plugsend-header h1 {
            color: #2c3e50;
            margin: 0;
            display: flex;
            align-items: center;
        }
        .plugsend-header .dashicons-whatsapp {
            color: #25D366;
            font-size: 40px;
            margin-right: 15px;
        }
        .plugsend-form {
            background: white;
            border-radius: 8px;
            padding: 30px;
            box-shadow: 0 5px 15px rgba(0,0,0,0.05);
        }
        .plugsend-placeholders {
            background: #f4f4f4;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 15px;
        }
        .plugsend-placeholders > div {
            background: white;
            padding: 15px;
            border-radius: 6px;
            box-shadow: 0 3px 6px rgba(0,0,0,0.05);
        }
        .plugsend-form-grid {
            display: grid;
            grid-template-columns: 1fr;
            gap: 20px;
        }
        .plugsend-form-group {
            margin-bottom: 15px;
        }
        .plugsend-form-group label {
            display: block;
            margin-bottom: 8px;
            color: #34495e;
            font-weight: 600;
        }
        .plugsend-form-group input[type="text"],
        .plugsend-form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .plugsend-form-group input[type="text"]:focus,
        .plugsend-form-group textarea:focus {
            border-color: #25D366;
            box-shadow: 0 0 8px rgba(37,211,102,0.2);
        }
        .submit-btn {
            background-color: #25D366;
            color: white;
            border: none;
            padding: 12px 30px;
            border-radius: 6px;
            font-weight: bold;
            transition: background-color 0.3s ease;
            width: 100%;
        }
        .submit-btn:hover {
            background-color: #20b355;
        }
    </style>
    <?php
}
add_action('admin_head', 'plugsend_api_admin_styles');

// Página de configuração do plugin
function plugsend_api_page() {
    ?>
    <div class="wrap plugsend-container">
        <div class="plugsend-header">
            <h1>
                <span class="dashicons dashicons-whatsapp"></span>
                PlugSend API - Configurações
            </h1>
        </div>
        
        <div class="plugsend-placeholders">
            <div>
                <strong>{id_pedido}</strong>
                <p>Número de identificação único do pedido</p>
            </div>
            <div>
                <strong>{nome_cliente}</strong>
                <p>Nome do cliente que realizou o pedido</p>
            </div>
            <div>
                <strong>{email_cliente}</strong>
                <p>Endereço de e-mail do cliente</p>
            </div>
            <div>
                <strong>{valor_total}</strong>
                <p>Valor total do pedido</p>
            </div>
            <div>
                <strong>{itens_pedido}</strong>
                <p>Lista de produtos comprados no pedido</p>
            </div>
        </div>
        
        <form method="post" action="options.php" class="plugsend-form">
            <div class="plugsend-form-grid">
                <?php
                settings_fields('plugsend_api_options');
                do_settings_sections('plugsend-api');
                submit_button('Salvar Configurações', 'primary submit-btn', 'submit', true);
                ?>
            </div>
        </form>
    </div>
    <?php
}

// Registrar configurações
function plugsend_api_register_settings() {
    add_settings_section('plugsend_api_section', 'Configurações da API do WhatsApp', null, 'plugsend-api');
    
    $fields = [
        'whatsapp_api_host' => 'Host da API do WhatsApp',
        'whatsapp_api_connection_key' => 'ConnectionKey da API do WhatsApp',
        'whatsapp_api_token' => 'Token da API do WhatsApp',
        'whatsapp_codigo_pais' => 'Código do País para WhatsApp'
    ];
    
    $message_fields = [
        'whatsapp_message_processing' => 'Mensagem para Pedido Processando',
        'whatsapp_message_completed' => 'Mensagem para Pedido Concluído',
        'whatsapp_message_failed' => 'Mensagem para Pedido Falho',
        'whatsapp_message_cancelled' => 'Mensagem para Pedido Cancelado'
    ];
    
    foreach ($fields as $id => $label) {
        add_settings_field($id, $label, function() use ($id) {
            $value = get_option($id, '');
            echo '<div class="plugsend-form-group">';
            echo '<label for="' . $id . '">' . esc_html($label) . '</label>';
            echo '<input type="text" id="' . $id . '" name="' . $id . '" value="' . esc_attr($value) . '">';
            echo '</div>';
        }, 'plugsend-api', 'plugsend_api_section');
        register_setting('plugsend_api_options', $id);
    }
    
    foreach ($message_fields as $id => $label) {
        add_settings_field($id, $label, function() use ($id) {
            $message = get_option($id);
            echo '<div class="plugsend-form-group">';
            echo '<label for="' . $id . '">' . esc_html($label) . '</label>';
            echo '<textarea id="' . $id . '" name="' . $id . '" class="large-text" rows="4">' . esc_textarea($message) . '</textarea>';
            echo '</div>';
        }, 'plugsend-api', 'plugsend_api_section');
        register_setting('plugsend_api_options', $id);
    }
}
add_action('admin_init', 'plugsend_api_register_settings');

// Funções de envio de mensagem (mantidas iguais ao plugin original)
add_action('woocommerce_order_status_processing', 'pluga_api_enviar_mensagem_processando');
add_action('woocommerce_order_status_completed', 'pluga_api_enviar_mensagem_concluido');
add_action('woocommerce_order_status_failed', 'pluga_api_enviar_mensagem_falhou');
add_action('woocommerce_order_status_cancelled', 'pluga_api_enviar_mensagem_cancelado');

function pluga_api_enviar_mensagem_processando($order_id) {
    pluga_api_enviar_mensagem($order_id, 'whatsapp_message_processing');
}

function pluga_api_enviar_mensagem_concluido($order_id) {
    pluga_api_enviar_mensagem($order_id, 'whatsapp_message_completed');
}

function pluga_api_enviar_mensagem_falhou($order_id) {
    pluga_api_enviar_mensagem($order_id, 'whatsapp_message_failed');
}

function pluga_api_enviar_mensagem_cancelado($order_id) {
    pluga_api_enviar_mensagem($order_id, 'whatsapp_message_cancelled');
}

function pluga_api_enviar_mensagem($order_id, $message_option) {
    $order = wc_get_order($order_id);
    if (!$order) return;

    $mensagem_template = get_option($message_option);
    if (empty($mensagem_template)) return;

    $mensagem = pluga_api_substituir_placeholders($mensagem_template, $order);

    pluga_api_enviar_mensagem_via_api($order, $mensagem);
}

function pluga_api_substituir_placeholders($template, $order) {
    $placeholders = [
        '{id_pedido}' => $order->get_id(),
        '{nome_cliente}' => $order->get_billing_first_name(),
        '{email_cliente}' => $order->get_billing_email(),
        '{valor_total}' => $order->get_total(),
        '{itens_pedido}' => pluga_api_obter_itens_pedido($order)
    ];

    foreach ($placeholders as $key => $value) {
        $template = str_replace($key, $value, $template);
    }
    return $template;
}

function pluga_api_obter_itens_pedido($order) {
    $items_string = '';
    foreach ($order->get_items() as $item) {
        $nome_produto = $item->get_name();
        $items_string .= "$nome_produto\n";
    }
    return $items_string;
}

function pluga_api_enviar_mensagem_via_api($order, $mensagem) {
    $codigo_pais = get_option('whatsapp_codigo_pais', '+55');
    $telefone_destinatario = preg_replace('/\D/', '', $order->get_billing_phone());
    $telefone_destinatario = $codigo_pais . $telefone_destinatario;

    $host = get_option('whatsapp_api_host');
    $connection_key = get_option('whatsapp_api_connection_key');
    $token = get_option('whatsapp_api_token');
    $api_url = "https://{$host}/message/sendText?connectionKey={$connection_key}";

    if (!$api_url || !$token) {
        error_log('Configurações da API do WhatsApp não estão definidas corretamente.');
        return;
    }

    $data = array(
        'phoneNumber' => $telefone_destinatario,
        'message' => $mensagem
    );

    $response = wp_remote_post($api_url, array(
        'method' => 'POST',
        'headers' => array(
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $token
        ),
        'body' => json_encode($data)
    ));

    if (is_wp_error($response)) {
        error_log('Erro ao enviar mensagem pelo WhatsApp: ' . $response->get_error_message());
    }
}